# ConfigChain

The key feature of ConfigChain, is the ability to dynamically create a hierarchical configuration by composition and override it through config files and the command line. 

**configchain 0.3.3** is the stable version of ConfigChain.
- Installation : `pip install configchain --upgrade`

### License
ConfigChain is licensed under [MIT License](LICENSE).